--- loncom/interface/loncreateuser.pm 2014/02/16 15:38:52 1.393
+++ loncom/interface/loncreateuser.pm 2014/02/28 19:20:06 1.395
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# Create a user
#
-# $Id: loncreateuser.pm,v 1.393 2014/02/16 15:38:52 raeburn Exp $
+# $Id: loncreateuser.pm,v 1.395 2014/02/28 19:20:06 bisitz Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -1813,7 +1813,7 @@ sub display_existing_roles {
}
} else {
$plaintext=
- &mt('Customrole [_1][_2]defined by [_3]',
+ &mt('Custom role [_1][_2]defined by [_3]',
'"'.$croletitle.'"',
'
',
$croleuname.':'.$croleudom);
@@ -2236,11 +2236,11 @@ sub personal_data_display {
if (($context eq 'selfcreate') && ($newuser eq 'email')) {
$output .= &Apache::lonhtmlcommon::row_title($lt{'email'},undef,
'LC_oddrow_value')."\n".
- '';
+ '';
$rowcount ++;
$output .= &Apache::lonhtmlcommon::row_closure(1);
- my $upassone = '';
- my $upasstwo = '';
+ my $upassone = '';
+ my $upasstwo = '';
$output .= &Apache::lonhtmlcommon::row_title(&mt('Password'),
'LC_pick_box_title',
'LC_oddrow_value')."\n".
@@ -2266,7 +2266,7 @@ sub personal_data_display {
} else {
if ($context eq 'selfcreate') {
if ($canmodify{$item}) {
- $row .= '';
+ $row .= '';
$editable ++;
} else {
$hiderow = 1;
@@ -2282,9 +2282,9 @@ sub personal_data_display {
} else {
if ($canmodify{$item}) {
if ($newuser eq 'email') {
- $row .= '';
+ $row .= '';
} else {
- $row .= '';
+ $row .= '';
}
$editable ++;
} else {
@@ -2715,7 +2715,7 @@ sub update_user_data {
$r->print($error.'Invalid login mode or password'.$end.$rtnlink);
return;
}
# Only allow authentification modification if the person has authority
if (&Apache::lonnet::allowed('mau',$env{'form.ccdomain'})) {
$r->print('Modifying authentication: '.
&Apache::lonnet::modifyuserauth(
@@ -2725,7 +2725,7 @@ sub update_user_data {
($env{'form.ccuname'},$env{'form.ccdomain'}));
} else {
# Okay, this is a non-fatal error.
- $r->print($error.&mt('You do not have the authority to modify this users authentification information').'.'.$end);
+ $r->print($error.&mt('You do not have the authority to modify this users authentication information.').$end);
}
}
$r->rflush(); # Finish display of header before time consuming actions start
@@ -2715,7 +2715,7 @@ sub update_user_data {
return;
}
- # Only allow authentification modification if the person has authority
+ # Only allow authentication modification if the person has authority
if (&Apache::lonnet::allowed('mau',$env{'form.ccdomain'})) {
$r->print('Modifying authentication: '.